@@ -15,7 +15,7 @@
 #' If the SDMX connection fails, a message is emitted (not a warning) and
 #' the function contines as if \code{useABSConnection = FALSE}.
 #' 
-#' The internal data was updated on 2020-03-16 to 2020-01-01.
+#' The internal data was updated on 2020-07-02 to 2020-05-01.
 #' @param allow.projection Logical. Should projections be allowed?
 #' @param use.month An integer (corresponding to the output of \code{data.table::month}) representing the month of the series used for the inflation.
 #' @param forecast.series Whether to use the forecast mean, or the upper or lower boundaries of the prediction intervals.
@@ -152,6 +152,9 @@ lf_inflator_fy <- function(labour_force = 1,
   
   if (useABSConnection) {
     # nocov start
+    if (!requireNamespace("rsdmx", quietly = TRUE)) {
+      stop("`useABSConnection = TRUE`, yet package:rsdmx is not installed.")  # nocov
+    }
     lf.indices <- 
       tryCatch({
         lf.url.trend <- 
