@@ -6,7 +6,7 @@ skip_on_circleci <- function(node = NULL) {
     if (identical(Sys.getenv("CIRCLECI"), "true")) {
       if (is.null(node)) {
         testthat::skip("On Circle-CI")
-      } else if (!identical(Sys.getenv("CIRCLECI_NODE_INDEX"), as.character(node))) {
+      } else if (identical(Sys.getenv("CIRCLECI_NODE_INDEX"), as.character(node))) {
         testthat::skip(paste0("On Circle-CI node != ", as.character(node)))
       }
     }
